scoreYJpn.object: Objects returned by the function 'scoreYJpn'

scoreYJpn.objectR Documentation

Objects returned by the function scoreYJpn

Description

An object of class scoreYJpn.object holds information about the result of a call to scoreYJpn.

Value

The functions print() and summary() are used to obtain and print a summary of the results. An object of class scoreYJpn is a list containing at least the following components:

  • la: vector containing the values of lambda for which the test is computed

  • Score: Matrix of size length(lambda)-by-3 that contains the value of the score test for each value of lambda specified in optional input parameter la. The first column refers to the test for positive observations, the second column refers to the test for negative observations and the third column refers to the F test for the joint presence of the two constructed variables. If la is not specified, the number of rows of the matrix Score is equal to 5 and will contain the values of the score test for the 5 most common values of lambda.

Examples


 ## Not run: 
     set.seed(1234)
     n <- 100
     y <- rnorm(n)
     ## Transform the value to find out if we can recover the true value of
     ## the transformation parameter.
     la <- 0.5
 ##    ytra <- normYJ(y,[],la,'inverse',true);
     ytra <- y
     
     ## Start the analysis
     X <- rep(1, n)
     (outSCpn <- scoreYJpn(X, ytra, intercept=FALSE))
     class(outSCpn)
     summary(outSCpn)
 
## End(Not run)

fsdaR documentation built on May 20, 2026, 1:07 a.m.