tclustreg.object: Objects returned by the function 'tclustreg'

tclustreg.objectR Documentation

Objects returned by the function tclustreg

Description

An object of class tclustreg.object holds information about the result of a call to tclustreg.

Value

The functions print() and summary() are used to obtain and print a summary of the results. An object of class tclustreg is a list containing at least the following components:

call

the matched call

bopt

a (p+1)-times-k matrix containing the regression parameters.

sigma2opt

a k-vector containing the estimated group variances.

sigma2opt_corr

a k-vector containing the estimated group variances corrected with asymptotic consistency factor.

muXopt

a k-by-p matrix containing cluster centroid locations. Robust estimate of final centroids of the groups. This output is present only if alphaX=1.

sigmaXopt

a p-by-p-by-k array containing estimated constrained covariance covariance matrices of the explanatory variables for the k groups. This output is present only if alphaX=1.

cstepopt

the concentration step where the objective function was the largest. This is useful when the objective function is not monotone (e.g. with second level trimming or with thinning).

subsetopt

the subset id where the objective function was the largest.

idx

an n-by-1 vector containing the assignment of each unit to each of the k groups. Cluster names are integer numbers from -2 to k where -1 indicates first level trimmed units and -2 - second level trimmed units.

size

a matrix of size k-by-3:

  • 1st col sequence from -2 to k

  • 2nd col number of observations in each cluster

  • 3rd col percentage of observations in each cluster

Remark: 0 denotes thinned units (if the weights to find thinned units are 0 or 1, -1 indicates first level trimmed units and -2 indicates second level trimmed units).

postprobopt

n-times-k matrix containing the final posterior probabilities. postprobopt[i,j] contains the posterior probabilitiy of unit i from component (cluster) j. For the trimmed units posterior probabilities are 0. This output is always produced (independently of the value of mixt).

MIXMIX

BIC which uses parameters estimated using the mixture loglikelihood and the maximized mixture likelihood as goodness of fit measure. This output is present only if mixt > 0.

MIXCLA

BIC which uses the classification likelihood based on parameters estimated using the mixture likelihood (In some books this quantity is called ICL). This output is present only if mixt > 0.

CLACLA

BIC which uses the classification likelihood based on parameters estimated using the classification likelihood. This output is present only if mixt > 0.

obj

the value of the objective function.

fullsol

a vector of size nsamp which contains the value of the objective function (maximized log likelihood) at the end of the iterative process for each extracted subsample. Note that max(fullsol) is equal to obj.

NlogL

-2 log of the classification likelihood. In the presence of full convergence -NlogL/2 is equal obj.

NlogLmixt

-2 log of the mixture likelihood. In the presence of full convergence -NlogLmixt/2 is equal to obj. If mixt=0 then NlogLmixt is empty.

See Also

tclustreg

Examples


 ## Not run: 

 ## The X data have been introduced by Gordaliza, Garcia-Escudero & Mayo-Iscar (2013).
 ## The dataset presents two parallel components without contamination.

 data(X)
 y1 = X[, ncol(X)]
 X1 = X[,-ncol(X), drop=FALSE]

 out <- tclustreg(y1, X1, k=2, alphaLik=0.05, alphaX=0.01, restrfactor=5, trace=TRUE)
 class(out)
 str(out)
 
## End(Not run)

fsdaR documentation built on May 20, 2026, 1:07 a.m.