wool: Wool data.

woolR Documentation

Wool data.

Description

The wool data give the number of cycles to failure of a worsted yarn under cycles of repeated loading. The variables are: length of test specimen; amplitude of loading cycle; load

Usage

data(wool)

Format

A data frame with 27 rows and 4 variables


fsdaR documentation built on May 20, 2026, 1:07 a.m.