| fanplot | R Documentation |
Plots the fan plot for transformation in linear regression
fanplot(
out,
xlab = "Subset of size m",
ylab = "Score test statistic",
main = "Fan plot",
xlim,
ylim,
cex.lab,
cex.axis,
lwd = 2,
lwd.env = 1,
tag,
datatooltip,
label,
nameX,
databrush,
conflev,
trace = FALSE,
...
)
out |
An object of S3 class
|
xlab |
A title for the x axis |
ylab |
A title for the y axis |
main |
An overall title for the plot |
xlim |
Controls the |
ylim |
Controls the |
cex.lab |
The magnification to be used for x and y labels relative to the current setting of cex |
cex.axis |
The magnification to be used for axis annotation relative to the current setting of cex |
lwd |
The line width, a positive number, default is |
lwd.env |
Width of the envelope lines. Default is |
tag |
Plot handle. String which identifies the handle of the plot which is about to be created. The default is to use tag 'pl_resfwd'. Notice that if the program finds a plot which has a tag equal to the one specified by the user, then the output of the new plot overwrites the existing one in the same window else a new window is created. |
datatooltip |
Interactive clicking. It is inactive if this parameter is set to FALSE.
The default is
|
label |
Character vector containing the labels of the units (optional argument used when
|
nameX |
Add variable labels in plot. A vector of strings of length |
databrush |
Interactive mouse brushing. If databrush is missing or empty (default), no brushing is done.
The activation of this option (databrush is If If
|
conflev |
confidence interval for the horizontal bands. It can be a vector of different confidence level values, e.g. c(0.95, 0.99, 0.999). The confidence interval is based on the $chi^2$ distribution. |
trace |
Whether to print intermediate results. Default is |
... |
potential further arguments passed to lower level functions. |
none
FSDA team, valentin.todorov@chello.at
Atkinson, A.C. and Riani, M. (2000), Robust Diagnostic Regression Analysis Springer Verlag, New York.
Atkinson, A.C. and Riani, M. (2002), Tests in the fan plot for robust, diagnostic transformations in regression, Chemometrics and Intelligent Laboratory Systems, 60, pp. 87–100.
Atkinson, A.C. Riani, M. and Corbellini A. (2019), The analysis of transformations for profit-and-loss data, Journal of the Royal Statistical Society, Series C, "Applied Statistics", 69, pp. 251–275. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/rssc.12389")}
Atkinson, A.C. Riani, M. and Corbellini A. (2021), The Box-Cox Transformation: Review and Extensions, Statistical Science, 36(2), pp. 239–255. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/20-STS778")}.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.