| scoreYJ.object | R Documentation |
scoreYJAn object of class scoreYJ.object holds information about
the result of a call to scoreYJ.
The functions print() and summary() are used to obtain and print a
summary of the results. An object of class scoreYJ is a list containing at least the following components:
la: vector containing the values of lambda for which fan plot is constructed
Score: a vector containing the values of the score test for
each value of the transformation parameter.
ScoreT: value of the Tukey's one degree of freedome test for non-additivity.
This output is produced only if tukey1df=TRUE.
Lik: value of the likelihood. This output is produced only if lik=TRUE.
## Not run:
data(wool)
XX <- wool
y <- XX[, ncol(XX)]
X <- XX[, 1:(ncol(XX)-1), drop=FALSE]
(out <- scoreYJ(X, y, lik=TRUE))
class(out)
summary(out)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.