| tclustreg.object | R Documentation |
tclustregAn object of class tclustreg.object holds information about
the result of a call to tclustreg.
The functions print() and summary() are used to obtain and print a
summary of the results. An object of class tclustreg is a list containing at least the following components:
call |
the matched call |
bopt |
a |
sigma2opt |
a |
sigma2opt_corr |
a |
muXopt |
a |
sigmaXopt |
a |
cstepopt |
the concentration step where the objective function was the largest. This is useful when the objective function is not monotone (e.g. with second level trimming or with thinning). |
subsetopt |
the subset id where the objective function was the largest. |
idx |
an |
size |
a matrix of size
Remark: 0 denotes thinned units (if the weights to find thinned units are 0 or 1, -1 indicates first level trimmed units and -2 indicates second level trimmed units). |
postprobopt |
|
MIXMIX |
BIC which uses parameters estimated using the mixture loglikelihood and the maximized mixture likelihood as goodness of fit measure.
This output is present only if |
MIXCLA |
BIC which uses the classification likelihood based on parameters estimated using the mixture likelihood (In some books this quantity is called ICL).
This output is present only if |
CLACLA |
BIC which uses the classification likelihood based on parameters estimated using the classification likelihood.
This output is present only if |
obj |
the value of the objective function. |
fullsol |
a vector of size |
NlogL |
-2 log of the classification likelihood. In the presence of full convergence |
NlogLmixt |
-2 log of the mixture likelihood. In the presence of full convergence - |
tclustreg
## Not run:
## The X data have been introduced by Gordaliza, Garcia-Escudero & Mayo-Iscar (2013).
## The dataset presents two parallel components without contamination.
data(X)
y1 = X[, ncol(X)]
X1 = X[,-ncol(X), drop=FALSE]
out <- tclustreg(y1, X1, k=2, alphaLik=0.05, alphaX=0.01, restrfactor=5, trace=TRUE)
class(out)
str(out)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.